@@ -32,76 +32,88 @@
 #include <panel/plugins.h>
 #include <panel/xfce.h>
 
-#define APPLET_PIXMAP ICONDIR "/note.png"
+#define APPLET_PIXMAP ICONDIR "/note_xfce.png"
+
+#define ICON_SIZE_SMALL 24
+#define ICON_SIZE_MEDIUM 30
+#define ICON_SIZE_LARGE 48
+#define ICON_SIZE_HUGE 60
+
 #define ICON_W 12
 #define ICON_H 12
 
 typedef struct __note {
-    /* the window */
-    GtkWidget *note_w;
-    GtkWidget *close_button;
-    GtkWidget *text_view;
+  /* the window */
+  GtkWidget *note_w;
+  GtkWidget *button_close;
+  GtkWidget *text_view;
+  
+  /* title */
+  GtkWidget *label_title;
+  GtkWidget *entry_title;
+  
+  /* needed to colour setting */
+  GtkWidget *event_box_top_left;
+  GtkWidget *event_box_top_middle;
+  GtkWidget *event_box_top_right;
+  GtkWidget *event_box_middle_left;
+  GtkWidget *event_box_middle_right;
+  GtkWidget *event_box_bottom_left;
+  GtkWidget *event_box_bottom_middle;
+  GtkWidget *event_box_bottom_right;
 
-    /* title */
-    GtkWidget *title_label;
-    GtkWidget *title_entry;
-
-    /* needed to colour setting */
-    GtkWidget *event_box_move1;
-    GtkWidget *event_box_move2;
-    GtkWidget *event_box_resize;
-
-    /* pointer to the tag <note></note> */
-    xmlNodePtr xml_tag;
-
-    gint x, y;
-    gint w, h;
-
-    gint id;
-
-} Note;
+  /* pointer to the tag <note></note> */
+  xmlNodePtr xml_tag;
+  
+  gint x, y;
+  gint w, h;
+  
+  gint id;
+  
+} _note;
 
 typedef struct __note_applet {
-    /* all notes */
-    GList *notes;
-    /* config  */
-    xmlDocPtr doc;
-
-    /* tooltips */
-    GtkTooltips *tooltips;
+  /* all notes */
+  GList *notes;
+  /* config  */
+  xmlDocPtr doc;
+  
+  /* tooltips */
+  GtkTooltips *tooltips;
     
-    /* needed for set_resize */
-    GtkWidget *event_box;
-    /* pixbuf of icon shown in panel */
-    GdkPixbuf *pixbuf;
-    gchar *icon_filename;
+  GtkWidget *applet_event_box;
+  GtkWidget *applet_button;
 
-    /* note pixbufs */
-    GdkPixbuf *close_pixbuf, *resize_pixbuf;
-
-    gint panel_size;
-
-    /* notes edited flag */
-    gboolean notes_saved;
-
-    /* user color */
-    GdkColor note_color;
-    gboolean system_colors;
-
-    /* other options */
-    gboolean notes_sticky;
-    gboolean show_notes;
-
-    /* save timeout */
-    int save_id;
-} NoteApplet;
+  /* pixbuf of icon shown in panel */
+  GdkPixbuf *pixbuf;
+  GtkWidget *icon;
+  gchar *icon_filename;
+  
+  //gint applet_size; /* SMALL, MEDIUM, LARGE or HUGE */
+  gint applet_icon_size; /* pixel size of icon */
+  
+  /* notes edited flag */
+  gboolean notes_saved;
+  
+  /* user color */
+  GdkColor note_color;
+  gboolean system_colors;
+  
+  /* other options */
+  gboolean notes_sticky;
+  gboolean notes_on_top;
+  gboolean show_notes;
+  
+  /* save timeout */
+  int save_id;
+} _note_applet;
 
 
 /* function declarations */
 
 /* notes_applet.c */
 void
-notes_update_note_colors(Note *note);
+notes_update_note_colors(_note *note);
 void
 notes_update_colors(void);
 void
@@ -109,11 +121,17 @@ notes_set_tooltips(void);
 void
 notes_update_sticky(void);
 void
+notes_update_on_top(void);
+void
 notes_update_visibility(void);
 gboolean 
 on_applet_button_press_event(GtkWidget *widget, GdkEventButton *event, 
 			     gpointer data);
 gboolean 
+on_applet_button_press_event_advanced(GtkWidget *widget, 
+				      GdkEventButton *event, 
+				      gpointer data);
+gboolean 
 notes_load_config(void);
 void 
 notes_store_config(void);
@@ -122,16 +140,18 @@ notes_new_note_with_attr(gchar *text, gchar *title,
 			 gint x, gint y, gint w, gint h);
 void
 notes_note_changed(GtkEditable *editable, gpointer data);
-Note*
+_note*
 notes_new_note(void);
 void
 notes_set_size(Control *ctrl, int size);
 
 /* notes_options.c */
 void
-on_sticky_check_button_toggled(GtkToggleButton *button, gpointer data);
+cb_sticky_check_button_toggled(GtkToggleButton *button, gpointer data);
 void
-on_system_colors_check_button_toggled(GtkToggleButton *button, gpointer data);
+cb_notes_on_top_check_button_toggled(GtkToggleButton *button, gpointer data);
+void
+cb_system_colors_check_button_toggled(GtkToggleButton *button, gpointer data);
 void
 notes_color_selection_ok(GtkDialog *color_dialog);
 void
@@ -147,7 +167,7 @@ notes_create_applet_options(GtkContainer *con);
 gboolean
 on_title_change(GtkWidget *widget, GdkEventButton *event, gpointer data);
 void
-on_title_change_done(Note *note);
+on_title_change_done(_note *note);
 gboolean
 on_title_key_press(GtkWidget *widget, GdkEventKey *event, gpointer data);
 gboolean
@@ -158,7 +178,7 @@ gboolean
 on_resize_window(GtkWidget *widget, GdkEventButton *event, gpointer data);
 void
 notes_init_note(void);
-Note*
+_note*
 notes_create_note(void);
 
     
